Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Faker ¶
type Faker struct {
Rand *core.Rand
Person *person.Person
Color *color.Color
Address *address.Address
Barcode *barcode.Barcode
Company *company.Company
File *file.File
Image *image.Image
Internet *internet.Internet
Lorem *lorem.Lorem
Medical *medical.Medical
Payment *payment.Payment
PhoneNumber *phonenumber.PhoneNumber
UserAgent *useragent.UserAgent
}
Faker is the main entry point that aggregates all fake data generators.
すべてのフェイクデータジェネレーターを集約するメインのエントリーポイント構造体。
func Create ¶
func Create() *Faker
Create creates a new Faker instance with the default en_US locale.
デフォルトのen_USロケールで新しいFakerインスタンスを作成する。
func CreateWithLocale ¶
CreateWithLocale creates a new Faker instance with the specified locale data.
指定されたロケールデータで新しいFakerインスタンスを作成する。
func CreateWithLocaleAndSeed ¶ added in v0.0.8
CreateWithLocaleAndSeed creates a new Faker instance with the specified locale data and a fixed seed, producing deterministic output.
指定されたロケールデータと固定シードで新しいFakerインスタンスを作成する。
func CreateWithSeed ¶ added in v0.0.8
CreateWithSeed creates a new Faker instance with the default en_US locale and a fixed seed, producing deterministic output (useful for tests / golden files).
デフォルトのen_USロケールと固定シードで新しいFakerインスタンスを作成する。 出力は決定的になる(テストやゴールデンファイル向け)。