Documentation
¶
Index ¶
Constants ¶
const ( JPG = ImageFormat("jpg") PNG = ImageFormat("png") GIF = ImageFormat("gif") )
const MaxHeightWidth = 3840
MaxHeightWidth is the maximum allowed width and height in pixels (3840px).
許可される最大の幅と高さ(3840ピクセル)。
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Image ¶
type Image struct {
// contains filtered or unexported fields
}
Image provides methods for generating random dummy images.
ランダムなダミー画像を生成するメソッドを提供する構造体。
func New ¶
New creates a new Image instance with the given random source and global data.
指定されたランダムソースとグローバルデータで新しいImageインスタンスを作成する。
func (*Image) Base64 ¶
Base64 generates a white blank image as a Base64-encoded string. Width and height should be 3840px or less.
白い空白画像をBase64エンコードされた文字列として生成する。 幅と高さは3840ピクセル以下にすること。
type ImageFormat ¶
type ImageFormat string
ImageFormat represents the image file format.
画像ファイルのフォーマットを表す型。
Click to show internal directories.
Click to hide internal directories.